# Generated by Django 3.2.8 on 2022-01-12 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ConfirmationState',
            fields=[
                ('id', models.UUIDField(primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.TextField(verbose_name='Confirmation code')),
                ('is_confirmed', models.BooleanField(default=False, max_length=512, verbose_name='Confirmed')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
            ],
            options={
                'verbose_name': 'Confirmation state',
                'verbose_name_plural': 'Confirmation states',
            },
        ),
    ]
