# Generated by Django 2.2 on 2022-04-06 14:36

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('wcd_2factor', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='confirmationstate',
            name='meta',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict, verbose_name='Metadata'),
        ),
        migrations.AlterField(
            model_name='confirmationstate',
            name='id',
            field=models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
